Type: Package
Package: admiralneuro
Title: Neuroscience Extension Package for ADaM in 'R' Asset Library
Version: 0.2.1
Authors@R: c(
    person("Jian", "Wang", , "wang_jian_wj@lilly.com", role = c("aut", "cre"),
           comment = c(ORCID = "0009-0002-4677-3781")),
    person("Miles", "Almond", role = "aut",
           comment = c(ORCID = "0009-0007-1784-0355")),
    person("Xiao", "Chen", role = "aut",
           comment = c(ORCID = "0009-0000-6959-5151")),
    person("Fanny", "Gautier", role = "aut",
           comment = c(ORCID = "0009-0004-3581-0131")),
    person("Gayatri", "G.", role = "aut"),
    person("Meilin", "Jiang", role = "aut",
           comment = c(ORCID = "0000-0003-4515-4567")),
    person("Leena", "Khatri", role = "aut",
           comment = c(ORCID = "0000-0002-2268-4023")),
    person("Edoardo", "Mancini", role = "aut",
           comment = c(ORCID = "0009-0006-4899-8641")),
    person("Eric", "Nantz", role = "aut"),
    person("Lina", "Patil", role = "aut"),
    person("Chris", "Pelentrides", role = "aut"),
    person("Eli Lilly and Company", role = c("cph", "fnd")),
    person("Cytel Inc.", role = c("cph", "fnd")),
    person("F. Hoffmann-La Roche AG", role = c("cph", "fnd"))
  )
Description: Programming neuroscience specific Clinical Data Standards
    Interchange Consortium (CDISC) compliant Analysis Data Model (ADaM)
    datasets in 'R'.  ADaM datasets are a mandatory part of any New Drug
    or Biologics License Application submitted to the United States Food
    and Drug Administration (FDA). Analysis derivations are implemented in
    accordance with the "Analysis Data Model Implementation Guide" (CDISC
    Analysis Data Model Team, 2021,
    <https://www.cdisc.org/standards/foundational/adam>). This package
    extends the 'admiral' package.
License: Apache License (>= 2)
BugReports: https://github.com/pharmaverse/admiralneuro/issues
URL: https://pharmaverse.github.io/admiralneuro/,
        https://github.com/pharmaverse/admiralneuro
Depends: R (>= 4.1)
Imports: admiral (>= 1.4.1), admiraldev (>= 1.4.0), cli (>= 3.6.2),
        dplyr (>= 1.1.1), hms (>= 0.5.3), lifecycle (>= 0.1.0),
        lubridate (>= 1.7.4), magrittr (>= 1.5), purrr (>= 0.3.3),
        rlang (>= 0.4.4), stringr (>= 1.4.0), tibble (>= 3.2.1), tidyr
        (>= 1.0.2), tidyselect (>= 1.1.0)
Suggests: diffdf, DT, htmltools, knitr, metatools, methods,
        pharmaversesdtm (>= 1.0.0), reactable, readxl, rmarkdown,
        testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-02-04 19:49:09 UTC; c085541
Author: Jian Wang [aut, cre] (ORCID: <https://orcid.org/0009-0002-4677-3781>),
  Miles Almond [aut] (ORCID: <https://orcid.org/0009-0007-1784-0355>),
  Xiao Chen [aut] (ORCID: <https://orcid.org/0009-0000-6959-5151>),
  Fanny Gautier [aut] (ORCID: <https://orcid.org/0009-0004-3581-0131>),
  Gayatri G. [aut],
  Meilin Jiang [aut] (ORCID: <https://orcid.org/0000-0003-4515-4567>),
  Leena Khatri [aut] (ORCID: <https://orcid.org/0000-0002-2268-4023>),
  Edoardo Mancini [aut] (ORCID: <https://orcid.org/0009-0006-4899-8641>),
  Eric Nantz [aut],
  Lina Patil [aut],
  Chris Pelentrides [aut],
  Eli Lilly and Company [cph, fnd],
  Cytel Inc. [cph, fnd],
  F. Hoffmann-La Roche AG [cph, fnd]
Maintainer: Jian Wang <wang_jian_wj@lilly.com>
Repository: CRAN
Date/Publication: 2026-02-04 23:20:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:32:54 UTC; unix
