# Generated by roxygen2: do not edit by hand

export(compute_centiloid)
export(compute_upsit_percentile)
importFrom(admiral,derive_vars_dy)
importFrom(admiraldev,
  assert_character_scalar,
  assert_character_vector,
  assert_data_frame,
  assert_filter_cond,
  assert_logical_scalar,
  assert_numeric_vector,
  assert_symbol,
  assert_vars
)
importFrom(cli,
  cli_abort,
  cli_warn
)
importFrom(dplyr,
  arrange,
  bind_cols,
  bind_rows,
  case_when,
  coalesce,
  desc,
  distinct,
  ends_with,
  filter,
  full_join,
  group_by,
  if_else,
  mutate,
  mutate_at,
  mutate_if,
  n,
  n_distinct,
  na_if,
  pull,
  rename,
  rename_at,
  row_number,
  select,
  slice,
  starts_with,
  summarise,
  summarise_at,
  tibble,
  transmute,
  ungroup,
  union,
  vars
)
importFrom(hms,as_hms)
importFrom(lifecycle,
  deprecate_stop,
  deprecate_warn,
  deprecated
)
importFrom(lubridate,
  "%--%",
  as_datetime,
  ceiling_date,
  date,
  days,
  duration,
  floor_date,
  hours,
  is.Date,
  is.instant,
  minutes,
  time_length,
  weeks,
  years,
  ymd,
  ymd_hms
)
importFrom(magrittr,"%>%")
importFrom(purrr,
  compose,
  every,
  flatten,
  keep,
  map,
  map2,
  map_chr,
  map_if,
  map_lgl,
  modify_at,
  modify_if,
  reduce,
  transpose,
  walk
)
importFrom(rlang,
  ":=",
  .data,
  abort,
  arg_match,
  as_function,
  as_string,
  call2,
  call_name,
  caller_env,
  current_env,
  enexpr,
  enquo,
  eval_bare,
  eval_tidy,
  expr,
  expr_interp,
  expr_label,
  f_lhs,
  f_rhs,
  inform,
  is_bare_formula,
  is_call,
  is_character,
  is_formula,
  is_integerish,
  is_logical,
  is_quosure,
  is_quosures,
  is_symbol,
  new_formula,
  parse_expr,
  parse_exprs,
  quo,
  quo_get_env,
  quo_get_expr,
  quo_is_call,
  quo_is_missing,
  quo_is_null,
  quo_is_symbol,
  quo_set_env,
  quo_squash,
  quo_text,
  quos,
  set_names,
  sym,
  syms,
  type_of,
  warn
)
importFrom(stringr,
  str_c,
  str_detect,
  str_extract,
  str_glue,
  str_remove,
  str_remove_all,
  str_replace,
  str_to_lower,
  str_to_title,
  str_to_upper,
  str_trim
)
importFrom(tibble,tribble)
importFrom(tidyr,
  drop_na,
  nest,
  pivot_longer,
  pivot_wider,
  unnest
)
importFrom(tidyselect,
  all_of,
  contains,
  vars_select
)
importFrom(utils,
  capture.output,
  str
)
